<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Panel Report</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css">
    <style>
        body {
            background-color: #f8f9fa;
        }

        .table thead th {
            background-color: #343a40;
            color: #fff;
        }

        .table tfoot td {
            background-color: #343a40;
            color: #fff;
            font-weight: bold;
        }

        .modal-header {
            background-color: #343a40;
            color: #fff;
        }

        .modal-footer .btn-primary {
            background-color: #343a40;
        }

        .total-row td {
            font-weight: bold;
        }
    </style>
</head>

<body>
    <?php include 'header.php'; ?>
    <div class="container mt-5">
        <h1 class="text-center mb-4">Panel Report</h1>
        <div class="row mb-3">
            <div class="col text-right">
                <button class="btn btn-primary" data-toggle="modal" data-target="#addRecordModal">Add Record</button>
            </div>
        </div>
        <div class="table-responsive">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th style="min-width: 118px;">Date</th>
                        <th style="min-width: 184px;">Kilometers</th>
                        <th>ΕΣΟΔΑ</th>
                        <th>ΕΞΟΔΑ</th>
                        <th>ΤΥΠΟΣ ΕΞΟΔΩΝ</th>
                        <th style="min-width: 132px;">Actions</th>
                    </tr>
                </thead>
                <tbody id="recordsTableBody">
                    <?php
                    
                    
                    
                    $totalKilometers = 0;
                    $totalIncome = 0;
                    $totalExpense = 0;
                    foreach ($records as $record) {
                        $date = date('d/m/Y', strtotime($record->date));
                        echo "<tr data-id='{$record->id}'>
                                <td>{$date}</td>
                                <td>{$record->kilometers}</td>
                                <td>{$record->income}</td>
                                <td>{$record->expense}</td>
                                <td>{$record->expense_type}</td>
                                <td>
                                    <button class='btn btn-warning btn-sm edit-btn' data-toggle='modal' data-target='#editRecordModal'>Edit</button>
                                    <button class='btn btn-danger btn-sm delete-btn'>Delete</button>
                                </td>
                              </tr>";
                        $totalKilometers += $record->kilometers;
                        $totalIncome += $record->income;
                        $totalExpense += $record->expense ?? 0; // Handle null expense
                    }
                    ?>
                </tbody>
                <tfoot>
                    <tr class="total-row">
                        <td>Grand Total:</td>
                        <td id="totalKilometers"><?= $totalKilometers ?></td>
                        <td id="totalIncome"><?= number_format($totalIncome, 0) ?></td>
                        <td id="totalExpense"><?= number_format($totalExpense, 0) ?></td>
                        <td></td>
                        <td></td>
                    </tr>
                </tfoot>
            </table>
        </div>
    </div>

    <!-- Modal for adding records -->
    <div class="modal fade" id="addRecordModal" tabindex="-1" role="dialog" aria-labelledby="addRecordModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addRecordModalLabel">Add Record</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <form id="addRecordForm">
                        <div class="form-group">
                            <label for="date">Date</label>
                            <input type="date" id="date" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="kilometers">Kilometers</label>
                            <input type="number" id="kilometers" class="form-control">
                        </div>
                        <div class="form-group">
                            <label for="income">Total Income</label>
                            <input type="number" id="income" class="form-control">
                        </div>
                        <div class="form-group">
                            <label for="expense">Total Expense</label>
                            <input type="number" id="expense" class="form-control">
                        </div>
                        <div class="form-group">
                            <label for="expense_type">Expense Type</label>
                            <select id="expense_type" class="form-control">
                                <option value="" selected>--</option>
                                <option value="ΠΕΤΡΑΙΛΕΟ">ΠΕΤΡΑΙΛΕΟ</option>
                                <option value="ΠΛΥΣΙΜΟ">ΠΛΥΣΙΜΟ</option>
                                <option value="ΣΥΝΕΡΓΕΙΟ">ΣΥΝΕΡΓΕΙΟ</option>
                            </select>
                        </div>
                        <button type="submit" class="btn btn-primary">Add Record</button>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal for editing records -->
    <div class="modal fade" id="editRecordModal" tabindex="-1" role="dialog" aria-labelledby="editRecordModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editRecordModalLabel">Edit Record</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <form id="editRecordForm">
                        <input type="text" id="edit_id">
                        <div class="form-group">
                            <label for="edit_date">Date</label>
                            <input type="date" id="edit_date" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="edit_kilometers">Kilometers</label>
                            <input type="number" id="edit_kilometers" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="edit_income">Total Income</label>
                            <input type="number" id="edit_income" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="edit_expense">Total Expense</label>
                            <input type="number" id="edit_expense" class="form-control">
                        </div>
                        <div class="form-group">
                            <label for="edit_expense_type">Expense Type</label>
                            <select id="edit_expense_type" class="form-control">
                                <option value="" selected>--</option>
                                <option value="ΠΕΤΡΑΙΛΕΟ">ΠΕΤΡΑΙΛΕΟ</option>
                                <option value="ΠΛΥΣΙΜΟ">ΠΛΥΣΙΜΟ</option>
                                <option value="ΣΥΝΕΡΓΕΙΟ">ΣΥΝΕΡΓΕΙΟ</option>
                            </select>
                        </div>
                        <button type="submit" class="btn btn-primary">Save Changes</button>
                    </form>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#addRecordForm').on('submit', function(event) {
                event.preventDefault();

                const date = $('#date').val();
                //const date = formatDate($('#date').val());
                const kilometers = parseFloat($('#kilometers').val()) || 0;
                const income = parseFloat($('#income').val()) || 0;
                const expense = parseFloat($('#expense').val()) || 0; // Handle null expense
                const expenseType = $('#expense_type').val();

                $.ajax({
                    url: '<?= base_url("Main/save_record") ?>',
                    method: 'POST',
                    data: {
                        date: date,
                        kilometers: kilometers,
                        income: income,
                        expense: expense,
                        expense_type: expenseType
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        console.log(result);
                        if (result.success) {
                            const tableBody = $('#recordsTableBody');
                            const newRow = $(`
                                <tr data-id="${result.id}">
                                    <td>${formatDate(date)}</td>
                                    <td>${kilometers.toFixed(0)}</td>
                                    <td>${income.toFixed(0)}</td>
                                    <td>${expense.toFixed(0)}</td>
                                    <td>${expenseType}</td>
                                    <td>
                                        <button class="btn btn-warning btn-sm edit-btn" data-toggle="modal" data-target="#editRecordModal">Edit</button>
                                        <button class="btn btn-danger btn-sm delete-btn">Delete</button>
                                    </td>
                                </tr>
                            `);

                            tableBody.append(newRow);
                            updateTotals(kilometers, income, expense);

                            //$('#addRecordModal').modal('hide');
                            $('#addRecordModal').removeClass('show');
                            $('#addRecordModal').hide();
                            $('body').removeClass('modal-open');
                            $('.modal-backdrop').remove();
                            $("#addRecordModal").removeAttr("aria-modal");
                            $("#addRecordModal").attr("aria-hidden","true");
                            
                            $('#addRecordForm')[0].reset();
                        } else {
                            alert('Error saving record.');
                        }
                    }
                });
            });

            $('#recordsTableBody').on('click', '.edit-btn', function() {
                const row = $(this).closest('tr');
                const id = row.data('id');
                const date = row.find('td:eq(0)').text();
                const kilometers = parseFloat(row.find('td:eq(1)').text()) || 0;
                const income = parseFloat(row.find('td:eq(2)').text()) || 0;
                const expense = parseFloat(row.find('td:eq(3)').text()) || 0; // Handle null expense
                const expenseType = row.find('td:eq(4)').text();

                $('#edit_id').val(id);
                //$('#edit_date').val(date);
                $('#edit_date').val(formatDateToInput(date));
                $('#edit_kilometers').val(kilometers);
                $('#edit_income').val(income);
                $('#edit_expense').val(expense);
                $('#edit_expense_type').val(expenseType);
            });

            $('#editRecordForm').on('submit', function(event) {
                event.preventDefault();

                const id = $('#edit_id').val();
                const date = $('#edit_date').val();
                //const date = formatDate($('#edit_date').val());
                const kilometers = parseFloat($('#edit_kilometers').val()) || 0;
                const income = parseFloat($('#edit_income').val()) || 0;
                const expense = parseFloat($('#edit_expense').val()) || 0; // Handle null expense
                const expenseType = $('#edit_expense_type').val();

                $.ajax({
                    url: '<?= base_url("Main/update_record") ?>',
                    method: 'POST',
                    data: {
                        id: id,
                        date: date,
                        kilometers: kilometers,
                        income: income,
                        expense: expense,
                        expense_type: expenseType
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        if (result.success) {
                            const row = $(`#recordsTableBody tr[data-id="${id}"]`);
                            const prevKilometers = parseFloat(row.find('td:eq(1)').text()) || 0;
                            const prevIncome = parseFloat(row.find('td:eq(2)').text()) || 0;
                            const prevExpense = parseFloat(row.find('td:eq(3)').text()) || 0; // Handle null expense

                            row.find('td:eq(0)').text(formatDate(date));
                            row.find('td:eq(1)').text(`${kilometers.toFixed(0)}`);
                            row.find('td:eq(2)').text(income.toFixed(0));
                            row.find('td:eq(3)').text(expense.toFixed(0));
                            row.find('td:eq(4)').text(expenseType);

                            $('#editRecordModal').modal('hide');

                            updateTotals(-prevKilometers + kilometers, -prevIncome + income, -prevExpense + expense);
                        } else {
                            alert('Error updating record.');
                        }
                    }
                });
            });

            $('#recordsTableBody').on('click', '.delete-btn', function() {
                const row = $(this).closest('tr');
                const id = row.data('id');

                if (confirm('Are you sure you want to delete this record?')) {
                    $.ajax({
                        url: '<?= base_url("Main/delete_record") ?>',
                        method: 'POST',
                        data: { id: id },
                        success: function(response) {
                            const result = JSON.parse(response);
                            if (result.success) {
                                const kilometers = parseFloat(row.find('td:eq(1)').text()) || 0;
                                const income = parseFloat(row.find('td:eq(2)').text()) || 0;
                                const expense = parseFloat(row.find('td:eq(3)').text()) || 0; // Handle null expense

                                updateTotals(-kilometers, -income, -expense);
                                row.remove();
                            } else {
                                alert('Error deleting record.');
                            }
                        }
                    });
                }
            });

            function updateTotals(kilometers, income, expense) {
                console.log(kilometers + " - " + income + " - " + expense);
                const totalKilometers = $('#totalKilometers');
                const totalIncome = $('#totalIncome');
                const totalExpense = $('#totalExpense');

                console.log(totalKilometers.text() + " - " + totalIncome.text() + " - " + totalExpense.text());
                const totalKilometers2 = totalKilometers.text().replace('KM','');
                const totalIncome2 = totalIncome.text().replace(',','');
                const totalExpense2 = totalExpense.text().replace(',','');
                console.log((parseFloat(totalKilometers2) + kilometers).toFixed(0) + " - " + (parseFloat(totalIncome2) + income).toFixed(0) + " - " + (parseFloat(totalExpense2) + expense).toFixed(0));
                
                
                totalKilometers.text((parseFloat(totalKilometers2) + kilometers).toFixed(0));
                totalIncome.text((parseFloat(totalIncome2) + income).toFixed(0));
                totalExpense.text((parseFloat(totalExpense2) + expense).toFixed(0));
            }
            
            function formatDate(date) {
                const d = new Date(date);
                let month = '' + (d.getMonth() + 1);
                let day = '' + d.getDate();
                const year = d.getFullYear();
    
                if (month.length < 2) month = '0' + month;
                if (day.length < 2) day = '0' + day;
    
                return [day, month, year].join('/');
            }
    
            function formatDateToInput(date) {
                const parts = date.split('/');
                const formattedDate = `${parts[2]}-${parts[0].padStart(2, '0')}-${parts[1].padStart(2, '0')}`;
                return formattedDate;
            }

            // Reset modal form on hide
            $('#addRecordModal').on('hidden.bs.modal', function () {
                $('#addRecordForm')[0].reset();
                $('body').removeClass('modal-open');
                $('.modal-backdrop').remove();
            });

            $('#editRecordModal').on('hidden.bs.modal', function () {
                $('#editRecordForm')[0].reset();
                $('body').removeClass('modal-open');
                $('.modal-backdrop').remove();
            });
        });
    </script>
</body>

</html>
